@@ -5,7 +5,7 @@ import imp
 import fnmatch
 import logging
 
-VERSION = (0, 3, 0)
+VERSION = (0, 3, 1)
 
 CO_VARARGS = 0x0004
 CO_VARKEYWORDS = 0x0008
@@ -41,10 +41,13 @@ class Plugin(object):
     def __init__(self, *args, **kwargs):
         pass
 
+def abspath(file_path):
+    return path.abspath(file_path) 
+
 
 def list_module(dir, pattern='*'):
+    log("search plugin path:'%s'" % dir)
     if path.isdir(dir):
-        log("search plugin path:'%s'" % dir)
         dir = path.realpath(dir)
         return [path.join(dir, file) for file in os.listdir(dir) if not
                 file.startswith('_') and file.endswith('.py') and
@@ -52,14 +55,16 @@ def list_module(dir, pattern='*'):
     return []
 
 def init_plugins(config, plugin_path=None, is_reload=False, pattern='*'):
-    plugin_path = plugin_path or ['./plugins']
+    plugin_path = plugin_path or [default_plugin_path]
     plugins = []
-    plugins.extend(list_module(default_plugin_path, pattern=pattern))
     
     plugin_pathes = plugin_path
     if not type(plugin_pathes) is list:
         plugin_pathes = [plugin_pathes]
-    
+    #plugin_pathes.append('./plugins')
+    plugin_pathes = map(abspath, plugin_pathes) 
+    log("plugin path:'%s'" % plugin_pathes)
+
     for plugin_path in plugin_pathes:
         if plugin_path:
             plugins.extend(list_module(plugin_path, pattern=pattern) or [])
@@ -83,8 +88,13 @@ def import_plugins(plugins, is_reload=False):
             
 def find_plugin(clazz):
     sub = clazz.__subclasses__()
-    log("find plugin class %s's plugin classes %s" % (clazz, sub))
     
+    tempdict = dict()
+    for s in sub:
+        tempdict[str(s)] = s 
+    sub = tempdict.values()
+    log("find %s's plugin : classes %s" % (clazz, sub))
+
     def _key(clazz):
         if hasattr(clazz, "priority"):
             return clazz.priority
@@ -136,7 +146,7 @@ def load_plugins(config, plugin_path=None, plugin_class=None,
     if debug:
         setup_log()
     
-    plugin_path = plugin_path or ['./plugins']
+    plugin_path = plugin_path or ['./plugins', default_plugin_path]
     plugin_class = plugin_class or [Plugin]
     ignore_class = ignore_class or []
 
